@@ -13,12 +13,14 @@
 # limitations under the License.
 # ============================================================================
 
+from .baseline_only import BaselineOnly
 from .bpr import BPR
 from .cdl import CDL
 from .c2pf import C2PF
 from .hpf import HPF
 from .pcrl import PCRL
 from .pmf import PMF
+from .nmf import NMF
 from .mcf import MCF
 from .vmf import VMF
 from .ibpr import IBPR
@@ -27,12 +29,17 @@ from .skm import SKMeans
 from .vbpr import VBPR
 from .online_ibpr import OnlineIBPR
 from .mf import MF
+from .svd import SVD
 from .conv_mf import ConvMF
 from .cdr import CDR
 from .sbpr import SBPR
 from .sorec import SoRec
 from .cvae import CVAE
-from .cf import CF
+from .wmf import WMF
 from .vaecf import VAECF
 from .ctr import CTR
 from .hft import HFT
+from .ncf import GMF
+from .ncf import MLP
+from .ncf import NeuMF
+from .efm import EFM
